import { TerminalStage } from '../../stages';
class MaxCollector extends TerminalStage {
    _comparator;
    _max;
    constructor(_comparator) {
        super();
        this._comparator = _comparator;
        if (!this._comparator) {
            this._comparator = (left, right) => {
                this._throwErrorIfNotNumber(left);
                this._throwErrorIfNotNumber(right);
                return left < right ? right : left;
            };
        }
    }
    _throwErrorIfNotNumber(value) {
        if (typeof value !== 'number') {
            throw new Error(`[max() collector] Numbers expected, erroneous pipeline element received was ${JSON.stringify(value)}`);
        }
    }
    consume(element) {
        if (!this._max) {
            this._max = element;
        }
        else {
            this._max = this._comparator(element, this._max);
        }
    }
    get() {
        return this._max;
    }
}
/**
 * Return a terminal stage that finds the max element in the pipeline. By default, if no comparator
 * function is provided, it assumes every element to be numeric, if at least one element is not numeric,
 * then it will throw an error. If a comparator function is provided, it will use the returned value of
 * the comparator as the max.
 *
 * @param comparator The comparing function that should return the max element between the 2 elements being compared.
 *
 * @template IN The type parameter of each incoming element in the pipeline.
 *
 * @returns
 */
export function max(comparator) {
    return new MaxCollector(comparator);
}
//# sourceMappingURL=max.js.map