import { TerminalStage } from '../../stages';
class SumCollector extends TerminalStage {
    _sum = 0;
    consume(element) {
        this._throwErrorIfNotNumber(element);
        this._sum += element;
    }
    _throwErrorIfNotNumber(value) {
        if (typeof value !== 'number') {
            throw new Error(`[sum() collector] Numbers expected, erroneous pipeline element received was ${JSON.stringify(value)}`);
        }
    }
    get() {
        return this._sum;
    }
}
/**
 * Return a terminal stage that calculates the sum of all elements in this pipeline. It assumes that every element
 * is numeric, otherwise, it will throw an error when at least one element is not numeric.
 *
 * @template IN The type parameter of each incoming element in the pipeline.
 *
 * @returns
 */
export function sum() {
    return new SumCollector();
}
//# sourceMappingURL=sum.js.map