import { IntermediateStage } from '../../stages';
class DistinctByStage extends IntermediateStage {
    _mapper;
    _seenElementMap = new Map();
    constructor(_mapper) {
        super();
        this._mapper = _mapper;
    }
    consume(element, hasMoreDataUpstream) {
        const distinctByElement = this._mapper(element);
        if (!this._seenElementMap.has(distinctByElement)) {
            this._downstream.consume(element, hasMoreDataUpstream);
            this._seenElementMap.set(distinctByElement, true);
        }
    }
    reset() {
        this._seenElementMap.clear();
        super.reset();
    }
}
/**
 * Return an intermediate stage that lets only unique elements pass through, uniqueness is decided by the provided mapper function.
 *
 * @param mapper The function used to get the value to use for uniqueness evaluation.
 *
 * @template IN The type parameter of each incoming element in the pipeline.
 *
 * @returns
 */
export function distinctBy(mapper) {
    return new DistinctByStage(mapper);
}
//# sourceMappingURL=distinctBy.js.map