/* eslint-disable jsdoc/check-indentation */
import { IntermediateStage } from '../../stages';
class FlatMapStage extends IntermediateStage {
    _flatMapper;
    constructor(_flatMapper) {
        super();
        this._flatMapper = _flatMapper;
    }
    consume(element, hasMoreDataUpstream) {
        const flattenedList = this._flatMapper(element);
        if (Array.isArray(flattenedList)) {
            const totalElement = flattenedList.length;
            for (let index = 0; index < totalElement; index++) {
                this._downstream.consume(flattenedList[index], hasMoreDataUpstream || index !== totalElement - 1);
            }
        }
        else {
            throw new Error(`[flatMap() operator] Element to flatMap did not generate an array, it was ${JSON.stringify(element)}`);
        }
    }
}
/**
 * Return an intermediate stage that flattens the inner array returned by the `flatMapper` argument into the pipeline.
 *
 * @param flatMapper A mapper function that returns an array from the upstream pipeline element, the returned array
 *                   is flattened into the pipeline so that each returned array's element will flow through the
 *                   pipeline one by one.
 *
 * @template IN The type parameter of each incoming element in the pipeline.
 * @template OUT The type parameter of each outgoing element to be forwarded to the downstream stage.
 *
 * @returns
 */
export function flatMap(flatMapper) {
    return new FlatMapStage(flatMapper);
}
//# sourceMappingURL=flatMap.js.map