/**
 * A stage in a pipeline. This abstract class defines the common APIs that each stage must support.
 *
 * @template IN The type parameter of each incoming element in the pipeline.
 */
export class Stage {
    /**
     * The list of subscribers that have registered for events that may be broadcast by this stage.
     */
    _eventSubscribers = [];
    /**
     * Reset this stage.
     */
    reset() {
        this._eventSubscribers = [];
    }
    /**
     * Notify all listeners of `event`.
     *
     * @param event The event with which to notify the listeners.
     */
    broadcast(event) {
        for (const subscriber of this._eventSubscribers) {
            subscriber(event, this);
        }
    }
    /**
     * Subscribe to the provided event.
     *
     * @param subscriber
     */
    subscribe(subscriber) {
        this._eventSubscribers.push(subscriber);
    }
}
//# sourceMappingURL=Stage.js.map